<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [Available Events](#available-events)
-   [Components](#components)
-   [AssetManager](#assetmanager)
-   [getConfig](#getconfig)
-   [getHtml](#gethtml)
-   [getCss](#getcss)
-   [getJs](#getjs)
-   [getComponents](#getcomponents)
-   [setComponents](#setcomponents)
-   [addComponents](#addcomponents)
-   [getStyle](#getstyle)
-   [setStyle](#setstyle)
-   [getSelected](#getselected)
-   [getSelectedToStyle](#getselectedtostyle)
-   [select](#select)
-   [setDevice](#setdevice)
-   [getDevice](#getdevice)
-   [runCommand](#runcommand)
-   [stopCommand](#stopcommand)
-   [store](#store)
-   [load](#load)
-   [getContainer](#getcontainer)
-   [setCustomRte](#setcustomrte)
-   [on](#on)
-   [off](#off)
-   [trigger](#trigger)
-   [render](#render)

## $

Editor class contains the top level API which you'll probably use to custom the editor or extend it with plugins.
You get the Editor instance on init method

```js
var editor = grapesjs.init({...});
```

# Available Events

## Components

-   `component:add` - Triggered when a new component is added to the editor, the model is passed as an argument to the callback
-   `component:update` - Triggered when a component is, generally, updated (moved, styled, etc.)
-   `component:update:{propertyName}` - Listen any property change
-   `component:styleUpdate` - Triggered when the style of the component is updated
-   `component:styleUpdate:{propertyName}` - Listen for a specific style property change
-   `component:selected` - New component selected
    ## Blocks
-   `block:add` - New block added
-   `block:remove` - Block removed
    ## Assets
-   `asset:add` - New asset added
-   `asset:remove` - Asset removed
-   `asset:upload:start` - Before the upload is started
-   `asset:upload:end` - After the upload is ended
-   `asset:upload:error` - On any error in upload, passes the error as an argument
-   `asset:upload:response` - On upload response, passes the result as an argument
    ## Keymaps
-   `keymap:add` - New keymap added. The new keyamp object is passed as an argument
-   `keymap:remove` - Keymap removed. The removed keyamp object is passed as an argument
-   `keymap:emit` - Some keymap emitted, in arguments you get keymapId, shortcutUsed, Event
-   `keymap:emit:{keymapId}` - `keymapId` emitted, in arguments you get keymapId, shortcutUsed, Event
    ## Style Manager
-   `styleManager:change` - Triggered on style property change from new selected component, the view of the property is passed as an argument to the callback
-   `styleManager:change:{propertyName}` - As above but for a specific style property
    ## Storages
-   `storage:start` - Before the storage request is started
-   `storage:load` - Triggered when something was loaded from the storage, loaded object passed as an argumnet
-   `storage:store` - Triggered when something is stored to the storage, stored object passed as an argumnet
-   `storage:end` - After the storage request is ended
-   `storage:error` - On any error on storage request, passes the error as an argument
    ## Selectors
-   `selector:add` - Triggers when a new selector/class is created
    ## RTE
-   `rte:enable` - RTE enabled. The view, on which RTE is enabled, is passed as an argument
-   `rte:disable` - RTE disabled. The view, on which RTE is disabled, is passed as an argument
    ## Commands
-   `run:{commandName}` - Triggered when some command is called to run (eg. editor.runCommand('preview'))
-   `stop:{commandName}` - Triggered when some command is called to stop (eg. editor.stopCommand('preview'))
    ## General
-   `canvasScroll` - Triggered when the canvas is scrolle
-   `load` - When the editor is loaded

**Parameters**

-   `config` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Configurations
    -   `config.container` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** ='' Selector for the editor container, eg. '#myEditor'
    -   `config.components` **([string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String) \| [Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)>)** HTML string or object of components (optional, default `''`)
    -   `config.style` **([string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String) \| [Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)>)** CSS string or object of rules (optional, default `''`)
    -   `config.fromElement` **[Boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** If true, will fetch HTML and CSS from selected container (optional, default `false`)
    -   `config.copyPaste` **[Boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** Enable/Disable the possibility to copy(ctrl + c) & paste(ctrl + v) components (optional, default `true`)
    -   `config.undoManager` **[Boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** Enable/Disable undo manager (optional, default `true`)
    -   `config.autorender` **[Boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** If true renders editor on init (optional, default `true`)
    -   `config.noticeOnUnload` **[Boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** Enable/Disable alert message before unload the page (optional, default `true`)
    -   `config.height` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Height for the editor container (optional, default `'900px'`)
    -   `config.width` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Width for the editor container (optional, default `'100%'`)
    -   `config.storage` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Storage manager configuration, see the relative documentation (optional, default `{}`)
    -   `config.styleManager` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Style manager configuration, see the relative documentation (optional, default `{}`)
    -   `config.commands` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Commands configuration, see the relative documentation (optional, default `{}`)
    -   `config.domComponents` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Components configuration, see the relative documentation (optional, default `{}`)
    -   `config.panels` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Panels configuration, see the relative documentation (optional, default `{}`)
    -   `config.showDevices` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** If true render a select of available devices inside style manager panel (optional, default `true`)
    -   `config.defaultCommand` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Command to execute when no other command is running (optional, default `'select-comp'`)
    -   `config.plugins` **[Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)** Array of plugins to execute on start (optional, default `[]`)
    -   `config.pluginsOpts` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Custom options for plugins (optional, default `{}`)

**Examples**

```javascript
var editor = grapesjs.init({
  container : '#gjs',
  components: '<div class="txt-red">Hello world!</div>',
  style: '.txt-red{color: red}',
});
```

## AssetManager

## getConfig

Returns configuration object

**Parameters**

-   `prop` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)?** Property name

Returns **any** Returns the configuration object or
 the value of the specified property

## getHtml

Returns HTML built inside canvas

Returns **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** HTML string

## getCss

Returns CSS built inside canvas

Returns **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** CSS string

## getJs

Returns JS of all components

Returns **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** JS string

## getComponents

Returns components in JSON format object

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)**

## setComponents

Set components inside editor's canvas. This method overrides actual components

**Parameters**

-   `components` **([Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)> | [Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object) \| [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String))** HTML string or components model

**Examples**

```javascript
editor.setComponents('<div class="cls">New component</div>');
// or
editor.setComponents({
 type: 'text',
  classes:['cls'],
  content: 'New component'
});
```

Returns **this**

## addComponents

Add components

**Parameters**

-   `components` **([Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)> | [Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object) \| [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String))** HTML string or components model
-   `opts` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Options
    -   `opts.avoidUpdateStyle` **[Boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** If the HTML string contains styles,
        by default, they will be created and, if already exist, updated. When this option
        is true, styles already created will not be updated. (optional, default `false`)

**Examples**

```javascript
editor.addComponents('<div class="cls">New component</div>');
// or
editor.addComponents({
 type: 'text',
  classes:['cls'],
  content: 'New component'
});
```

Returns **(Model | [Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;Model>)**

## getStyle

Returns style in JSON format object

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)**

## setStyle

Set style inside editor's canvas. This method overrides actual style

**Parameters**

-   `style` **([Array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)> | [Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object) \| [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String))** CSS string or style model

**Examples**

```javascript
editor.setStyle('.cls{color: red}');
//or
editor.setStyle({
  selectors: ['cls']
  style: { color: 'red' }
});
```

Returns **this**

## getSelected

Returns selected component, if there is one

Returns **Model**

## getSelectedToStyle

Get a stylable entity from the selected component.
If you select a component without classes the entity is the Component
itself and all changes will go inside its 'style' attribute. Otherwise,
if the selected component has one or more classes, the function will
return the corresponding CSS Rule

Returns **Model**

## select

Select a component

**Parameters**

-   `el` **(Component | [HTMLElement](https://developer.mozilla.org/en-US/docs/Web/HTML/Element))** Component to select

**Examples**

```javascript
// Select dropped block
editor.on('block:drag:stop', function(model) {
 editor.select(model);
});
```

Returns **this**

## setDevice

Set device to the editor. If the device exists it will
change the canvas to the proper width

**Parameters**

-   `name` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Name of the device

**Examples**

```javascript
editor.setDevice('Tablet');
```

Returns **this**

## getDevice

Return the actual active device

**Examples**

```javascript
var device = editor.getDevice();
console.log(device);
// 'Tablet'
```

Returns **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Device name

## runCommand

Execute command

**Parameters**

-   `id` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Command ID
-   `options` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Custom options

**Examples**

```javascript
editor.runCommand('myCommand', {someValue: 1});
```

Returns **any** The return is defined by the command

## stopCommand

Stop the command if stop method was provided

**Parameters**

-   `id` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Command ID
-   `options` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Custom options

**Examples**

```javascript
editor.stopCommand('myCommand', {someValue: 1});
```

Returns **any** The return is defined by the command

## store

Store data to the current storage

**Parameters**

-   `clb` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** Callback function

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Stored data

## load

Load data from the current storage

**Parameters**

-   `clb` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** Callback function

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Stored data

## getContainer

Returns container element. The one which was indicated as 'container'
on init method

Returns **[HTMLElement](https://developer.mozilla.org/en-US/docs/Web/HTML/Element)**

## setCustomRte

Replace the built-in Rich Text Editor with a custom one.

**Parameters**

-   `obj` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Custom RTE Interface

**Examples**

```javascript
editor.setCustomRte({
  // Function for enabling custom RTE
  // el is the HTMLElement of the double clicked Text Component
  // rte is the same instance you have returned the first time you call
  // enable(). This is useful if need to check if the RTE is already enabled so
  // ion this case you'll need to return the RTE and the end of the function
  enable: function(el, rte) {
    rte = new MyCustomRte(el, {}); // this depends on the Custom RTE API
    ...
    return rte; // return the RTE instance
  },

  // Disable the editor, called for example when you unfocus the Text Component
 disable: function(el, rte) {
    rte.blur(); // this depends on the Custom RTE API
 }

// Called when the Text Component is focused again. If you returned the RTE instance
// from the enable function, the enable won't be called again instead will call focus,
// in this case to avoid double binding of the editor
 focus: function (el, rte) {
  rte.focus(); // this depends on the Custom RTE API
 }
});
```

## on

Attach event

**Parameters**

-   `event` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Event name
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** Callback function

Returns **this**

## off

Detach event

**Parameters**

-   `event` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Event name
-   `callback` **[Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)** Callback function

Returns **this**

## trigger

Trigger event

**Parameters**

-   `event` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Event to trigger

Returns **this**

## render

Render editor

Returns **[HTMLElement](https://developer.mozilla.org/en-US/docs/Web/HTML/Element)**
